#!/bin/sh
#
# Script to insert links from all occurrences of each ftnchek option
# to the main description of the option in ftnchek.html.
#
# Author: Robert Moniot
# Date:   19 Jul 1998
#
#  Get list of all ftnchek main options, including the leading '-'.
options=`ftnchek -help | \
	  awk '/^ *-/ {split($0,command);
		 sub(/\[no\]/,"",command[1]);
		 sub(/=.*$/,"",command[1]);
		 print command[1];
		}'`

#  Turn list of options into a list of sed substitutions to change
#  them into hrefs.  The href is "#option" (without the -).
make_hrefs=`echo $options | sed "s@-\([a-z][-a-z0-9]*\)@ -e 's,-\1,<A HREF=\"#\1\">&</A>,g'@g"`

# Now create the cross-references.

# The first sed command creates anchors for all the option
# descriptions in main description section.  The second one
# substitutes hot-links to the former at all the places where the
# options occur in the text.  An eval is needed since the sed commands
# contain blanks which would make them parse into separate arguments.
# The third one puts hot-links in for the -[no]options in synopsis section
# that are not recognized by the second sed.

sed -e '/<H2><A NAME=.*Options/,/<H2><A NAME=/s,^<DT><B>-\([a-z][a-z0-9]*\)[^<]*</B>,<A NAME="\1"></A>&,' | \
eval sed $make_hrefs  | \
sed -e '/<H2><A NAME=.*Name/,/<H2><A NAME=.*Description/s,<B>-</B>\[<B>no</B>\]<B>\([a-z][-a-z0-9]*\),<A HREF="#\1">&</A>,g'


